@@ -1,7 +1,7 @@
 #!/bin/sh
 
 NDPI_MAJOR="3"
-NDPI_MINOR="0"
+NDPI_MINOR="4"
 NDPI_PATCH="0"
 NDPI_VERSION_SHORT="$NDPI_MAJOR.$NDPI_MINOR.$NDPI_PATCH"
 
@@ -12,10 +12,17 @@ AUTOMAKE=$(command -v automake)
 LIBTOOL=$(command -v libtool)
 LIBTOOLIZE=$(command -v libtoolize)
 AUTORECONF=$(command -v autoreconf)
+PKG_CONFIG=$(command -v pkg-config)
+FUZZY=
 
 if test -z $AUTOCONF; then
     echo "autoconf is missing: please install it and try again"
     exit
+else
+    V=`autoconf --version | head -1 | cut -d ' ' -f 4`
+    if [ "$V" = '2.63' ]; then
+        FUZZY="dnl> "
+    fi
 fi
 
 if test -z $AUTOMAKE; then
@@ -33,11 +40,17 @@ if test -z $AUTORECONF; then
     exit
 fi
 
+if test -z $PKG_CONFIG; then
+    echo "pkg-config is missing: please install it (apt-get install pkg-config) and try again"
+    exit
+fi
+
 cat configure.seed | sed \
     -e "s/@NDPI_MAJOR@/$NDPI_MAJOR/g" \
     -e "s/@NDPI_MINOR@/$NDPI_MINOR/g" \
     -e "s/@NDPI_PATCH@/$NDPI_PATCH/g" \
     -e "s/@NDPI_VERSION_SHORT@/$NDPI_VERSION_SHORT/g" \
+    -e "s/@FUZZY@/$FUZZY/g" \
     > configure.ac
 
 autoreconf -ivf
@@ -45,4 +58,5 @@ cat configure | sed "s/#define PACKAGE/#define NDPI_PACKAGE/g" | sed "s/#define
 cat configure.tmp > configure
 
 chmod +x configure
-./configure $*
+./configure $@
+
