@@ -1,7 +1,7 @@
 /*
  * dropbox.c
  *
- * Copyright (C) 2012-16 by ntop.org
+ * Copyright (C) 2012-18 by ntop.org
  *
  * This file is part of nDPI, an open source deep packet inspection
  * library based on the OpenDPI and PACE technology by ipoque GmbH
@@ -21,18 +21,18 @@
  * 
  */
 
+#include "ndpi_protocol_ids.h"
+
+#define NDPI_CURRENT_PROTO NDPI_PROTOCOL_DROPBOX
 
 #include "ndpi_api.h"
 
-#ifdef NDPI_PROTOCOL_DROPBOX
 
 #define DB_LSP_PORT 17500
 
-
 static void ndpi_int_dropbox_add_connection(struct ndpi_detection_module_struct *ndpi_struct,
 					    struct ndpi_flow_struct *flow,
-					    u_int8_t due_to_correlation)
-{
+					    u_int8_t due_to_correlation) {
   ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_DROPBOX, NDPI_PROTOCOL_UNKNOWN);
 }
 
@@ -46,28 +46,35 @@ static void ndpi_check_dropbox(struct ndpi_detection_module_struct *ndpi_struct,
   if(packet->udp != NULL) {
     u_int16_t dropbox_port = htons(DB_LSP_PORT);
 
-    if((packet->udp->source == dropbox_port)
-       && (packet->udp->dest == dropbox_port)) {
-      if(payload_len > 2) {
-	if(strncmp((const char *)packet->payload, "{\"host_int\"", 11) == 0) {
-	  
-	  NDPI_LOG(NDPI_PROTOCOL_DROPBOX, ndpi_struct, NDPI_LOG_DEBUG, "Found dropbox.\n");
-	  ndpi_int_dropbox_add_connection(ndpi_struct, flow, 0);
-	  return;
+    if(packet->udp->dest == dropbox_port) {    
+      if(packet->udp->source == dropbox_port) {	
+	if(payload_len > 10) {
+	  if(ndpi_strnstr((const char *)packet->payload, "\"host_int\"", payload_len) != NULL) {	    
+	    NDPI_LOG_INFO(ndpi_struct, "found dropbox\n");
+	    ndpi_int_dropbox_add_connection(ndpi_struct, flow, 0);
+	    return;
+	  }
+	}
+      } else {
+	if(payload_len > 10) {
+	  if(ndpi_strnstr((const char *)packet->payload, "Bus17Cmd", payload_len) != NULL) {	    
+	    NDPI_LOG_INFO(ndpi_struct, "found dropbox\n");
+	    ndpi_int_dropbox_add_connection(ndpi_struct, flow, 0);
+	    return;
+	  }
 	}
       }
     }
   }
   
-  NDPI_LOG(NDPI_PROTOCOL_DROPBOX, ndpi_struct, NDPI_LOG_DEBUG, "exclude dropbox.\n");
-  NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_DROPBOX);
+  NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
 }
 
 void ndpi_search_dropbox(struct ndpi_detection_module_struct *ndpi_struct, struct ndpi_flow_struct *flow)
 {
   struct ndpi_packet_struct *packet = &flow->packet;
 
-  NDPI_LOG(NDPI_PROTOCOL_DROPBOX, ndpi_struct, NDPI_LOG_DEBUG, "dropbox detection...\n");
+  NDPI_LOG_DBG(ndpi_struct, "search dropbox\n");
 
   /* skip marked packets */
   if (packet->detected_protocol_stack[0] != NDPI_PROTOCOL_DROPBOX) {
@@ -88,7 +95,3 @@ void init_dropbox_dissector(struct ndpi_detection_module_struct *ndpi_struct, u_
 				      ADD_TO_DETECTION_BITMASK);
   *id += 1;
 }
-
-
-
-#endif
