@@ -1,7 +1,7 @@
 /*
  * smb.c
  *
- * Copyright (C) 2016-19 - ntop.org
+ * Copyright (C) 2016-20 - ntop.org
  *
  * This file is part of nDPI, an open source deep packet inspection
  * library based on the OpenDPI and PACE technology by ipoque GmbH
@@ -21,7 +21,7 @@
  *
  */
 #include "ndpi_protocol_ids.h"
-
+#define NDPI_CURRENT_PROTO NDPI_PROTOCOL_SMBV23
 #include "ndpi_api.h"
 
 
@@ -33,18 +33,24 @@ void ndpi_search_smb_tcp(struct ndpi_detection_module_struct *ndpi_struct, struc
 
   /* Check connection over TCP */
   if(packet->tcp) {
+    u_int16_t fourfourfive =  htons(445);
     
-    if(packet->tcp->dest == htons(445)
+    if(((packet->tcp->dest == fourfourfive) || (packet->tcp->source == fourfourfive))
        && packet->payload_packet_len > (32 + 4 + 4)
        && (packet->payload_packet_len - 4) == ntohl(get_u_int32_t(packet->payload, 0))
-       && get_u_int32_t(packet->payload, 4) == htonl(0xff534d42)) {
-      
+       ) {
+      u_int8_t smbv1[] = { 0xff, 0x53, 0x4d, 0x42 };
+
       NDPI_LOG_INFO(ndpi_struct, "found SMB\n");
 
-      if(packet->payload[8] == 0x72)
-	ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_SMBV1, NDPI_PROTOCOL_UNKNOWN);
-      else
-	ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_SMBV23, NDPI_PROTOCOL_UNKNOWN);
+      if(memcmp(&packet->payload[4], smbv1, sizeof(smbv1)) == 0) {
+	if(packet->payload[8] != 0x72) /* Skip Negotiate request */ {	  
+	  ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_SMBV1, NDPI_PROTOCOL_NETBIOS);
+	  NDPI_SET_BIT(flow->risk, NDPI_SMB_INSECURE_VERSION);
+	}
+      } else
+	ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_SMBV23, NDPI_PROTOCOL_NETBIOS);
+
       return;
     }
   }
@@ -65,4 +71,3 @@ void init_smb_dissector(struct ndpi_detection_module_struct *ndpi_struct, u_int3
 
   *id += 1;
 }
-
